@@ -29,6 +29,12 @@ class ELISALIB_EXPORT ElisaConfigurationDialog : public QObject
                WRITE setForceUsageOfSlowFileSystemIndexing
                NOTIFY forceUsageOfSlowFileSystemIndexingChanged)
 
+Q_PROPERTY(bool showNowPlayingBackground
+               READ showNowPlayingBackground
+               WRITE setShowNowPlayingBackground
+               NOTIFY showNowPlayingBackgroundChanged)
+
+
     Q_PROPERTY(bool showProgressInTaskBar
                READ showProgressInTaskBar
                WRITE setShowProgressInTaskBar
@@ -63,6 +69,11 @@ class ELISALIB_EXPORT ElisaConfigurationDialog : public QObject
                    WRITE setColorScheme
                    NOTIFY colorSchemeChanged)
 
+    Q_PROPERTY(bool useFavoriteStyleRatings
+               READ useFavoriteStyleRatings
+               WRITE setUseFavoriteStyleRatings
+               NOTIFY useFavoriteStyleRatingsChanged)
+
 public:
 
     explicit ElisaConfigurationDialog(QObject *parent = nullptr);
@@ -76,6 +87,12 @@ public:
         return mIsDirty;
     }
 
+    [[nodiscard]] bool showNowPlayingBackground() const
+    {
+        return mShowNowPlayingBackground;
+    }
+
+
     [[nodiscard]] bool showProgressInTaskBar() const
     {
         return mShowProgressInTaskBar;
@@ -111,6 +128,11 @@ public:
         return mColorScheme;
     }
 
+    [[nodiscard]] bool useFavoriteStyleRatings() const
+    {
+        return mUseFavoriteStyleRatings;
+    }
+
     Q_INVOKABLE void removeMusicLocation(QString location);
 
 
@@ -120,6 +142,8 @@ Q_SIGNALS:
 
     void isDirtyChanged();
 
+    void showNowPlayingBackgroundChanged();
+
     void showProgressInTaskBarChanged();
 
     void showSystemTrayIconChanged();
@@ -134,6 +158,8 @@ Q_SIGNALS:
 
     void colorSchemeChanged();
 
+    void useFavoriteStyleRatingsChanged();
+
 public Q_SLOTS:
 
     void setRootPath(const QStringList &rootPath);
@@ -142,6 +168,8 @@ public Q_SLOTS:
 
     void cancel();
 
+    void setShowNowPlayingBackground(bool showNowPlayingBackground);
+
     void setShowProgressInTaskBar(bool showProgressInTaskBar);
 
     void setShowSystemTrayIcon(bool showSystemTrayIcon);
@@ -156,6 +184,8 @@ public Q_SLOTS:
 
     void setColorScheme(const QString &scheme);
 
+    void setUseFavoriteStyleRatings(bool useFavoriteStyleRatings);
+
 private Q_SLOTS:
 
     void configChanged();
@@ -170,6 +200,8 @@ private:
 
     bool mIsDirty = false;
 
+    bool mShowNowPlayingBackground = true;
+
     bool mShowProgressInTaskBar = true;
 
     bool mShowSystemTrayIcon = false;
@@ -178,6 +210,8 @@ private:
 
     bool mPlayAtStartup = false;
 
+    bool mUseFavoriteStyleRatings = false;
+
     QString mColorScheme;
 
     ElisaUtils::PlayListEntryType mEmbeddedView = ElisaUtils::Unknown;
