@@ -17,7 +17,7 @@
 #include "manageheaderbar.h"
 #include "audiowrapper.h"
 
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
 #include <KFileMetaData/EmbeddedImageData>
 #endif
 
@@ -118,7 +118,7 @@ bool MediaPlayer2Player::CanGoNext() const
 
 void MediaPlayer2Player::Next()
 {
-    emit next();
+    Q_EMIT next();
 
     if (m_playListControler) {
         m_playListControler->skipNextTrack();
@@ -132,7 +132,7 @@ bool MediaPlayer2Player::CanGoPrevious() const
 
 void MediaPlayer2Player::Previous()
 {
-    emit previous();
+    Q_EMIT previous();
 
     if (m_playListControler) {
         m_playListControler->skipPreviousTrack(m_audioPlayer->position());
@@ -153,7 +153,7 @@ void MediaPlayer2Player::Pause()
 
 void MediaPlayer2Player::PlayPause()
 {
-    emit playPause();
+    Q_EMIT playPause();
 
     if (m_playListControler) {
         m_manageAudioPlayer->playPause();
@@ -162,7 +162,7 @@ void MediaPlayer2Player::PlayPause()
 
 void MediaPlayer2Player::Stop()
 {
-    emit stop();
+    Q_EMIT stop();
 
     if (m_playListControler) {
         m_manageAudioPlayer->stop();
@@ -189,7 +189,7 @@ double MediaPlayer2Player::Volume() const
 void MediaPlayer2Player::setVolume(double volume)
 {
     m_volume= qBound(0.0, volume, 1.0);
-    emit volumeChanged(m_volume);
+    Q_EMIT volumeChanged(m_volume);
 
     m_audioPlayer->setVolume(100 * m_volume);
 
@@ -210,7 +210,7 @@ void MediaPlayer2Player::setPropertyPosition(int newPositionInMs)
 {
     m_position = qlonglong(newPositionInMs) * 1000;
 
-    /* only sent new progress when it has advanced more than 1 %
+    /* only send new progress when it has advanced more than 1 %
      * to limit DBus traffic
      */
     const auto incrementalProgress = static_cast<double>(newPositionInMs - mPreviousProgressPosition) / m_audioPlayer->duration();
@@ -238,7 +238,7 @@ void MediaPlayer2Player::setRate(double newRate)
         Pause();
     } else {
         m_rate = qBound(MinimumRate(), newRate, MaximumRate());
-        emit rateChanged(m_rate);
+        Q_EMIT rateChanged(m_rate);
 
         signalPropertiesChange(QStringLiteral("Rate"), Rate());
     }
@@ -304,8 +304,8 @@ void MediaPlayer2Player::playControlEnabledChanged()
     signalPropertiesChange(QStringLiteral("CanPause"), CanPause());
     signalPropertiesChange(QStringLiteral("CanPlay"), CanPlay());
 
-    emit canPauseChanged();
-    emit canPlayChanged();
+    Q_EMIT canPauseChanged();
+    Q_EMIT canPlayChanged();
 }
 
 void MediaPlayer2Player::skipBackwardControlEnabledChanged()
@@ -317,7 +317,7 @@ void MediaPlayer2Player::skipBackwardControlEnabledChanged()
     m_canGoPrevious = m_manageMediaPlayerControl->skipBackwardControlEnabled();
 
     signalPropertiesChange(QStringLiteral("CanGoPrevious"), CanGoPrevious());
-    emit canGoPreviousChanged();
+    Q_EMIT canGoPreviousChanged();
 }
 
 void MediaPlayer2Player::skipForwardControlEnabledChanged()
@@ -329,13 +329,13 @@ void MediaPlayer2Player::skipForwardControlEnabledChanged()
     m_canGoNext = m_manageMediaPlayerControl->skipForwardControlEnabled();
 
     signalPropertiesChange(QStringLiteral("CanGoNext"), CanGoNext());
-    emit canGoNextChanged();
+    Q_EMIT canGoNextChanged();
 }
 
 void MediaPlayer2Player::playerPlaybackStateChanged()
 {
     signalPropertiesChange(QStringLiteral("PlaybackStatus"), PlaybackStatus());
-    emit playbackStatusChanged();
+    Q_EMIT playbackStatusChanged();
 
     playerIsSeekableChanged();
 }
@@ -345,7 +345,7 @@ void MediaPlayer2Player::playerIsSeekableChanged()
     m_playerIsSeekableChanged = m_manageAudioPlayer->playerIsSeekable();
 
     signalPropertiesChange(QStringLiteral("CanSeek"), CanSeek());
-    emit canSeekChanged();
+    Q_EMIT canSeekChanged();
 }
 
 void MediaPlayer2Player::audioPositionChanged()
@@ -385,7 +385,7 @@ void MediaPlayer2Player::setCurrentTrack(int newTrackPosition)
     m_currentTrack = m_manageAudioPlayer->playerSource().toString();
     m_currentTrackId = QDBusObjectPath(QLatin1String("/org/kde/elisa/playlist/") + QString::number(newTrackPosition)).path();
 
-    emit currentTrackChanged();
+    Q_EMIT currentTrackChanged();
 
     m_metadata = getMetadataOfCurrentTrack();
     signalPropertiesChange(QStringLiteral("Metadata"), Metadata());
@@ -416,7 +416,7 @@ QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
         if (m_manageHeaderBar->image().scheme() == QStringLiteral("image")) {
             // adding a special case for image:// URLs that are only valid because Elisa installs a special handler for them
             // converting those URL to data URLs with embedded image data
-#if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
+#if KF5FileMetaData_FOUND
             KFileMetaData::EmbeddedImageData embeddedImage;
 
             auto imageData = embeddedImage.imageData(m_manageHeaderBar->image().toString().mid(14));
@@ -466,16 +466,16 @@ void MediaPlayer2Player::setMediaPlayerPresent(int status)
 {
     if (m_mediaPlayerPresent != status) {
         m_mediaPlayerPresent = status;
-        emit mediaPlayerPresentChanged();
+        Q_EMIT mediaPlayerPresentChanged();
 
         signalPropertiesChange(QStringLiteral("CanGoNext"), CanGoNext());
         signalPropertiesChange(QStringLiteral("CanGoPrevious"), CanGoPrevious());
         signalPropertiesChange(QStringLiteral("CanPause"), CanPause());
         signalPropertiesChange(QStringLiteral("CanPlay"), CanPlay());
-        emit canGoNextChanged();
-        emit canGoPreviousChanged();
-        emit canPauseChanged();
-        emit canPlayChanged();
+        Q_EMIT canGoNextChanged();
+        Q_EMIT canGoPreviousChanged();
+        Q_EMIT canPauseChanged();
+        Q_EMIT canPlayChanged();
     }
 }
 
